/* IRCfs - IRC FileServ for *nix.
 * Copyright (C) 2002  Nick 'Zaf' Clifford <zaf@nrc.co.nz>
 * For licensing details, refer to the LICENSE file in the source 
 * code directory.
 */
#ifndef __include_num_hash_h__
#define __include_num_hash_h__

#include <unistd.h>
#include <ctype.h>
#include <sys/types.h>
#include "runtime.h"

struct num_hash_table;

typedef int (*num_hash_callback_t)(struct num_hash_table *, int num,
		void *contents); 

struct num_hash_table *num_hash_create(POOL parent);
struct num_hash_table *num_hash_create_n(POOL parent, size_t buckets);
/* destroys a hash table.
 * free's any memory that *IT* allocated. eg
 * contents of nodes are *NOT* destroyed.
 * To do a total clean up, call hash_foreach, and free each
 * node yourself, then call hash_destroy
 */
int num_hash_destroy(struct num_hash_table *ht);

int num_hash_resize(struct num_hash_table *ht, size_t buckets);

int num_hash_foreach(struct num_hash_table *ht, num_hash_callback_t callback);

int num_hash_add(struct num_hash_table *ht, int num, void *contents);
int num_hash_set(struct num_hash_table *ht, int num, void *contents,
		void **old);


/* hash_del(ht,name)
 * Deletes node name from hash table.
 * Returns contents of node if found and deleted.
 * Otherwise returns NULL
 */
void *num_hash_del(struct num_hash_table *ht, int num);

void *num_hash_get(struct num_hash_table *ht, int num);

#endif
